@@ -2,9 +2,10 @@
 ** this is reserved for official patches released by me (the author - 
 ** Ashley Roll). If you have a patch then please release it via me - you 
 ** will be credited with creating it. You can E-Mail me at:
-** aroll@gucis.cit.gu.edu.au
+** A.Roll@cit.gu.edu.au or ash@splat.paxnet.com.au
 */
-#define PATCHLEVEL 01
+#define PATCHLEVEL "0"
+#define VERSION "3"
 
 /*********************************************************
 ** These patches applied before version 2.0 was written **
@@ -27,3 +28,8 @@
  * bug identified in get_pos() by George Phillips <phillips@cs.ubc.ca>
  * patch created by George Phillips <phillips@cs.ubc.ca>.
  */
+
+/**************************************
+** These are the version 3.0 patches **
+***************************************/
+
